ExpandedDimension

Enum ExpandedDimension 

pub enum ExpandedDimension {
    Length(f32),
    Percent(f32),
    Auto,
    MinContent,
    MaxContent,
    FitContentPx(f32),
    FitContentPercent(f32),
    FitContent,
    Stretch,
    Content,
    Calc(*const ()),
}
The expanded, non-compact representation of a Dimension.

Obtained via Dimension::expand. Can be converted back into a Dimension using the From implementation.

Variants



Length(f32)

An absolute length (see Dimension::length)



Percent(f32)

A percentage length (see Dimension::percent)



Auto

The automatic keyword (see Dimension::auto)



MinContent

The min-content keyword (see Dimension::min_content)



MaxContent

The max-content keyword (see Dimension::max_content)



FitContentPx(f32)

A fit-content(...) value with a length limit (see Dimension::fit_content_px)



FitContentPercent(f32)

A fit-content(...) value with a percentage limit (see Dimension::fit_content_percent)



FitContent

The fit-content keyword with no limit (see Dimension::fit_content)



Stretch

The stretch keyword (see Dimension::stretch)



Content

The content keyword (see Dimension::content)



Calc(*const ())

A calc() value (see Dimension::calc). The pointer is an opaque handle to the calc representation, exactly as passed to the constructor.