AlignItems

Struct AlignItems 

pub struct AlignItems {
    pub keyword: AlignItemsKeyword,
    pub safety: AlignmentSafety,
}
Used to control how child nodes are aligned. For Flexbox it controls alignment in the cross axis. For Grid it controls alignment in the block axis.

MDN

Fields

keyword: AlignItemsKeyword

Position keyword.

safety: AlignmentSafety

Overflow-position modifier (safe / unsafe).

Implementations

Source

impl AlignItems

pub const START: Self

Items are packed toward the start of the axis.

pub const END: Self

Items are packed toward the end of the axis.

pub const FLEX_START: Self

Items are packed towards the flex-relative start of the axis.

pub const FLEX_END: Self

Items are packed towards the flex-relative end of the axis.

pub const CENTER: Self

Items are packed along the center of the cross axis.

pub const BASELINE: Self

Items are aligned such as their baselines align.

pub const STRETCH: Self

Stretch to fill the container.

pub const SAFE_START: Self

Like AlignItems::START, but falls back to AlignItems::START when the alignment subject overflows the alignment container, to avoid data loss.

pub const SAFE_END: Self

Like AlignItems::END, but falls back to AlignItems::START when the alignment subject overflows the alignment container, to avoid data loss.

pub const SAFE_FLEX_START: Self

Like AlignItems::FLEX_START, but falls back to AlignItems::START when the alignment subject overflows the alignment container, to avoid data loss.

pub const SAFE_FLEX_END: Self

Like AlignItems::FLEX_END, but falls back to AlignItems::START when the alignment subject overflows the alignment container, to avoid data loss.

pub const SAFE_CENTER: Self

Like AlignItems::CENTER, but falls back to AlignItems::START when the alignment subject overflows the alignment container, to avoid data loss.

pub const fn is_safe(self) -> bool

Returns true iff this carries the safe overflow-position modifier.

pub const fn keyword(self) -> AlignItemsKeyword

Returns the underlying position keyword, discarding the safety modifier.