pub type JustifySelf = AlignItems;Expand description
Controls alignment of an individual node.
Overrides the parent Node’s JustifyItems property.
Does not apply to Flexbox, and will be ignored if specified on a flex child.
For Grid it controls alignment in the inline axis.
Aliased Type
pub struct JustifySelf {
pub keyword: AlignItemsKeyword,
pub safety: AlignmentSafety,
}Fields
keyword: AlignItemsKeywordPosition keyword.
safety: AlignmentSafetyOverflow-position modifier (safe / unsafe).